@@ -11,6 +11,8 @@ from experiments.generate_plots import (
 
 from experiments.utils import MSE,generate_episodes_and_calc_J
 
+from seldonian.RL.environments.gridworld import Gridworld
+
 @pytest.mark.parametrize('experiment', ["./tests/static/results"], indirect=True)
 def test_regression_plot_generator(gpa_regression_spec,experiment):
 	np.random.seed(42)
@@ -26,16 +28,9 @@ def test_regression_plot_generator(gpa_regression_spec,experiment):
 	# Get performance evaluation kwargs set up
 	# Use entire original dataset as ground truth for test set
 	dataset = spec.dataset
-	label_column = dataset.label_column
-	include_sensitive_columns = dataset.include_sensitive_columns
 
-	test_features = dataset.df.loc[:,
-		dataset.df.columns != label_column]
-	test_labels = dataset.df[label_column]
-
-	if not include_sensitive_columns:
-		test_features = test_features.drop(
-			columns=dataset.sensitive_column_names)	
+	test_features = dataset.features
+	test_labels = dataset.labels
 
 	# Define any additional keyword arguments (besides theta)
 	# of the performance evaluation function,
@@ -129,17 +124,8 @@ def test_classification_plot_generator(gpa_classification_spec,experiment):
 	# Get performance evaluation kwargs set up
 	# Use entire original dataset as ground truth for test set
 	dataset = spec.dataset
-	label_column = dataset.label_column
-	include_sensitive_columns = dataset.include_sensitive_columns
-
-	test_features = dataset.df.loc[:,
-		dataset.df.columns != label_column]
-	test_labels = dataset.df[label_column]
-
-	if not include_sensitive_columns:
-		test_features = test_features.drop(
-			columns=dataset.sensitive_column_names)	
-
+	test_features = dataset.features
+	test_labels = dataset.labels
 
 	# Define any additional keyword arguments (besides theta)
 	# of the performance evaluation function,
@@ -211,18 +197,17 @@ def test_classification_plot_generator(gpa_classification_spec,experiment):
 	fairlearn_eval_method = 'two-groups' # the epsilon used to evaluate g, needs to be same as epsilon in our definition
 	fairlearn_epsilons_constraint = [0.2] # the epsilons used in the fitting constraint
 	fairlearn_sensitive_feature_names=['M']
-	
+	fairlearn_sensitive_col_indices = [dataset.sensitive_col_names.index(
+	    col) for col in fairlearn_sensitive_feature_names]
+	fairlearn_sensitive_features = dataset.sensitive_attrs[:,fairlearn_sensitive_col_indices]
 	# Make dict of test set features, labels and sensitive feature vectors
-	if 'offset' in test_features.columns:
-		test_features_fairlearn = test_features.drop(columns=['offset'])
-	else:
-		test_features_fairlearn = test_features
+	
+	test_features_fairlearn = test_features
 
 	fairlearn_eval_kwargs = {
 		'X':test_features_fairlearn,
 		'y':test_labels,
-		'sensitive_features':dataset.df.loc[:,
-			fairlearn_sensitive_feature_names],
+		'sensitive_features':fairlearn_sensitive_features,
 		'eval_method':fairlearn_eval_method,
 		}
 
@@ -337,17 +322,9 @@ def test_too_few_datapoints(gpa_regression_spec,experiment):
 	# Get performance evaluation kwargs set up
 	# Use entire original dataset as ground truth for test set
 	dataset = spec.dataset
-	label_column = dataset.label_column
-	include_sensitive_columns = dataset.include_sensitive_columns
-
-	test_features = dataset.df.loc[:,
-		dataset.df.columns != label_column]
-	test_labels = dataset.df[label_column]
-
-	if not include_sensitive_columns:
-		test_features = test_features.drop(
-			columns=dataset.sensitive_column_names)	
 
+	test_features = dataset.features
+	test_labels = dataset.labels
 
 	# Define any additional keyword arguments (besides theta)
 	# of the performance evaluation function,
@@ -400,7 +377,7 @@ def test_too_few_episodes(gridworld_spec,experiment):
 	perf_eval_kwargs = {'n_episodes_for_eval':n_episodes_for_eval}
 	
 	hyperparameter_and_setting_dict = {}
-	hyperparameter_and_setting_dict["env"] = "gridworld"
+	hyperparameter_and_setting_dict["env"] = Gridworld()
 	hyperparameter_and_setting_dict["agent"] = "Parameterized_non_learning_softmax_agent"
 	hyperparameter_and_setting_dict["num_episodes"] = 1000
 	hyperparameter_and_setting_dict["num_trials"] = 1
@@ -456,7 +433,7 @@ def test_RL_plot_generator(gridworld_spec,experiment):
 	}
 	
 	hyperparameter_and_setting_dict = {}
-	hyperparameter_and_setting_dict["env"] = "gridworld"
+	hyperparameter_and_setting_dict["env"] = Gridworld()
 	hyperparameter_and_setting_dict["agent"] = "Parameterized_non_learning_softmax_agent"
 	hyperparameter_and_setting_dict["num_episodes"] = 1000
 	hyperparameter_and_setting_dict["num_trials"] = 1
